package cn.bunny.service.impl;

import cn.bunny.common.spzx.model.dto.product.ProductDto;
import cn.bunny.common.spzx.model.entity.product.Product;
import cn.bunny.common.spzx.model.entity.product.ProductDetails;
import cn.bunny.common.spzx.model.entity.product.ProductSku;
import cn.bunny.mapper.ProductDetailMapper;
import cn.bunny.mapper.ProductMapper;
import cn.bunny.mapper.ProductSkuMapper;
import cn.bunny.service.ProductService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class ProductServiceImpl implements ProductService {
    @Autowired
    private ProductMapper productMapper;

    @Autowired
    private ProductSkuMapper productSkuMapper;

    @Autowired
    private ProductDetailMapper productDetailMapper;

    // 查询分页
    @Override
    public PageInfo<Product> findByPage(Integer page, Integer limit, ProductDto productDto) {
        PageHelper.startPage(page, limit);
        List<Product> productList = productMapper.findByPage(productDto);
        return new PageInfo<>(productList);
    }

    // 保存商品数据接口
    @Override
    public void save(Product product) {
        product.setStatus(0);
        product.setAuditStatus(0);
        productMapper.save(product);

        List<ProductSku> productSkuList = product.getProductSkuList();
        for (int i = 0; i < productSkuList.size(); i++) {
            ProductSku productSku = productSkuList.get(i);
            // 商品编号
            productSku.setSkuCode(product.getId() + "_" + i);
            // 商品Id
            productSku.setProductId(product.getId());
            // skuName
            productSku.setSkuName(product.getName() + productSku.getSkuSpec());
            productSkuMapper.save(productSku);
        }

        ProductDetails productDetails = new ProductDetails();
        productDetails.setProductId(product.getId());
        productDetails.setImageUrls(product.getDetailsImageUrls());
        productDetailMapper.save(productDetails);
    }

    // 根据id查询商品信息
    @Override
    public Product getById(Long id) {
        // 1. 根据id查询商品基本信息
        Product product = productMapper.findProductById(id);

        // 2. 根据id查询商品sku信息列表 product——sku
        List<ProductSku> productSkuList = productSkuMapper.findProductSkuByProductId(id);
        product.setProductSkuList(productSkuList);

        // 3. 根据id查询商品详情信息 product——details
        ProductDetails productDetails = productDetailMapper.findProductDetailsById(id);
        String imageUrls = productDetails.getImageUrls();
        product.setDetailsImageUrls(imageUrls);

        return product;
    }

    // 保存修改数据
    @Override
    public void updateById(Product product) {
        // 修改product表
        productMapper.updateProduct(product);

        // 修改product_sku表
        List<ProductSku> productSkuList = product.getProductSkuList();
        for (ProductSku productSku : productSkuList) {
            productSkuMapper.updateById(productSku);
        }

        // 修改product_details表
        String detailsImageUrls = product.getDetailsImageUrls();
        ProductDetails productDetails= productDetailMapper.findProductDetailsById(product.getId());
        productDetails.setImageUrls(detailsImageUrls);
        productDetailMapper.updateById(productDetails);
    }
}
